/*
 *	$Id$
 */

#ifndef  __MKF_PROPERTY_H__
#define  __MKF_PROPERTY_H__


typedef enum mkf_property
{
	MKF_COMBINING = 0x1u ,

	/* only for UCS */
	MKF_FULLWIDTH = 0x2u ,
	MKF_AWIDTH = 0x4u

} mkf_property_t ;


#endif
